==> kubernetes-model-autoscaling-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2/ExternalMetricSourceFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ExternalMetricSourceFluent<A extends ExternalMetricSourceFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildMetric instead.
   * @return The buildable object.
   */
  @Deprecated
  public MetricIdentifier getMetric();
  public MetricIdentifier buildMetric();
  public A withMetric(MetricIdentifier metric);
  public Boolean hasMetric();
  public ExternalMetricSourceFluent.MetricNested<A> withNewMetric();
  public ExternalMetricSourceFluent.MetricNested<A> withNewMetricLike(MetricIdentifier item);
  public ExternalMetricSourceFluent.MetricNested<A> editMetric();
  public ExternalMetricSourceFluent.MetricNested<A> editOrNewMetric();
  public ExternalMetricSourceFluent.MetricNested<A> editOrNewMetricLike(MetricIdentifier item);
  
  /**
   * This method has been deprecated, please use method buildTarget instead.
   * @return The buildable object.
   */
  @Deprecated
  public MetricTarget getTarget();
  public MetricTarget buildTarget();
  public A withTarget(MetricTarget target);
  public Boolean hasTarget();
  public ExternalMetricSourceFluent.TargetNested<A> withNewTarget();
  public ExternalMetricSourceFluent.TargetNested<A> withNewTargetLike(MetricTarget item);
  public ExternalMetricSourceFluent.TargetNested<A> editTarget();
  public ExternalMetricSourceFluent.TargetNested<A> editOrNewTarget();
  public ExternalMetricSourceFluent.TargetNested<A> editOrNewTargetLike(MetricTarget item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetricNested<N> extends Nested<N>,MetricIdentifierFluent<ExternalMetricSourceFluent.MetricNested<N>>{
    public N and();
    public N endMetric();
    
  }
  public interface TargetNested<N> extends Nested<N>,MetricTargetFluent<ExternalMetricSourceFluent.TargetNested<N>>{
    public N and();
    public N endTarget();
    
  }
  
}

==> kubernetes-model-autoscaling-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2/ExternalMetricSourceFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ExternalMetricSourceFluent<A extends ExternalMetricSourceFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildMetric instead.
   * @return The buildable object.
   */
  @Deprecated
  public MetricIdentifier getMetric();
  public MetricIdentifier buildMetric();
  public A withMetric(MetricIdentifier metric);
  public Boolean hasMetric();
  public ExternalMetricSourceFluent.MetricNested<A> withNewMetric();
  public ExternalMetricSourceFluent.MetricNested<A> withNewMetricLike(MetricIdentifier item);
  public ExternalMetricSourceFluent.MetricNested<A> editMetric();
  public ExternalMetricSourceFluent.MetricNested<A> editOrNewMetric();
  public ExternalMetricSourceFluent.MetricNested<A> editOrNewMetricLike(MetricIdentifier item);
  
  /**
   * This method has been deprecated, please use method buildTarget instead.
   * @return The buildable object.
   */
  @Deprecated
  public MetricTarget getTarget();
  public MetricTarget buildTarget();
  public A withTarget(MetricTarget target);
  public Boolean hasTarget();
  public ExternalMetricSourceFluent.TargetNested<A> withNewTarget();
  public ExternalMetricSourceFluent.TargetNested<A> withNewTargetLike(MetricTarget item);
  public ExternalMetricSourceFluent.TargetNested<A> editTarget();
  public ExternalMetricSourceFluent.TargetNested<A> editOrNewTarget();
  public ExternalMetricSourceFluent.TargetNested<A> editOrNewTargetLike(MetricTarget item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetricNested<N> extends Nested<N>,MetricIdentifierFluent<ExternalMetricSourceFluent.MetricNested<N>>{
    public N and();
    public N endMetric();
    
  }
  public interface TargetNested<N> extends Nested<N>,MetricTargetFluent<ExternalMetricSourceFluent.TargetNested<N>>{
    public N and();
    public N endTarget();
    
  }
  
}
